# kindplay

Kind wrapper to spin up local playgrounds using kind. It's a helpful tool to prepare a reusable local cluster using yaml settings.


## Installing

```
pip install kindplay
```


## Usage

```
kindplay start <playground_path>
```

## playground structure

**root\kind.yaml**
    [kind configuration file](https://kind.sigs.k8s.io/docs/user/configuration/).